@@ -1,5 +1,6 @@
 from chatgpt_cli.conversation import Conversation, Template
 from utils.io import *
+import re
 
 
 def is_command(user_msg: str) -> bool:
@@ -34,6 +35,9 @@ def execute_command(
         conv.edit_messages()
     elif user_msg in ["!drop", "drop"]:
         conv.drop_messages()
+    elif user_msg in ["!editor", "editor"]:
+        message = input_from_editor()
+        user_msg += " " + message
     elif user_msg in ["!exit", "!quit", "quit", "exit"]:
         conv.save(True)
         print("Bye!")
@@ -43,3 +47,14 @@ def execute_command(
     elif user_msg.startswith("!"):
         print("Invalid command, please try again")
     return user_msg
+
+
+def post_command_process(user_message):
+    # handle the return string of execute_command
+    pattern = re.compile(r"^!\w*\s*")
+    if user_message.startswith("!editor"):
+        user_message = pattern.sub("", user_message)
+        user_output(user_message)
+    else:
+        user_message = pattern.sub("", user_message)
+    return user_message
